<?php


namespace Controllers;


use Exception\CustomException;
use Util\Utilities;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Services\PrivacyPolicy as PrivacyPolicyService;

class PrivacyPolicy extends Simple
{
    /** @var PrivacyPolicyService $privacyPolicyService */
    protected $privacyPolicyService;

    /**
     * PrivacyPolicy constructor.
     * @param PrivacyPolicyService $privacyPolicyService
     */
    public function __construct(PrivacyPolicyService $privacyPolicyService)
    {
        $this->privacyPolicyService = $privacyPolicyService;
    }

    public function uploadPrivacyPolicy(Request\DataSet $request, Response $response)
    {
        try {
            $rows     = $request->getDataSet()->getRows()[0];
            $pdfPath = $rows['UPLOAD_PRIVACY_POLICY'][0]['path'];
            $data = $this->privacyPolicyService->uploadPrivacyPolicy($pdfPath);
            $response->addDataSet(new DataSet ('uploadPrivacyPolicy', $data));
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }

    public function removePrivacyPolicy(Request\Filter $request, Response $response)
    {
        try {
            $data = $this->privacyPolicyService->removePrivacyPolicy();
            $response->addDataSet(new DataSet ('removePrivacyPolicy', $data));
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }

    public function findPrivacyPolicy(Request\Filter $request, Response $response)
    {
        try {
            $data = $this->privacyPolicyService->findPrivacyPolicy();
            $response->addDataSet(new DataSet ('findPrivacyPolicy', $data));
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }

    public function findPrivacyPolicyByAuthentication(Request\Filter $request, Response $response)
    {
        try {
            $conditiond = $request->getFilterCriteria()->getConditions();
            $user = Utilities::getValueInFilterDataSourceByName($conditiond, 'USER', true);
            $data = $this->privacyPolicyService->findPrivacyPolicyByAuthentication($user);
            $response->addDataSet(new DataSet ('findPrivacyPolicyByAuthentication', $data));
        } catch(CustomException $e) {
            $response->setError(Utilities::getErrorObjectFromException($e));
        }
    }
}